==> dungeon_world_data-3.0.2.tar.gz: lib/data/en-US/races.dart <==
import 'package:dungeon_world_data/race.dart';

List<Race> getRaceList() => [
      Race.fromJson({
        "_meta": {"language": "EN", "createdBy": "__repo__"},
        "key": "c0193cdc-e318-44e5-8229-fbbaf3a98936",
        "name": "Elf",
        "description":
            "When you enter an important location (your call) you can ask the GM for one fact from the history of that location.",
        "explanation": "",
        "classKeys": [
          {"key": "bard", "name": "Bard", "type": "CharacterClass"}
        ],
        "tags": [],
        "dice": []
      }),
      Race.fromJson({
        "_meta": {"language": "EN", "createdBy": "__repo__"},
        "key": "6ff63a18-529e-47d8-902e-8093808a9afa",
        "name": "Human",
        "description":
            "When you first enter a civilized settlement someone who respects the custom of hospitality to minstrels will take you in as their guest.",
        "explanation": "",
        "classKeys": [
          {"key": "bard", "name": "Bard", "type": "CharacterClass"}
        ],
        "tags": [],
        "dice": []
      }),
      Race.fromJson({
        "_meta": {"language": "EN", "createdBy": "__repo__"},
        "key": "a300fc64-19b4-4615-98f1-87dea6048cf2",
        "name": "Dwarf",
        "description":
            "You are one with stone. When you Commune you are also granted a special version of Words of the Unspeaking as a rote which only works on stone.",
        "explanation": "",
        "classKeys": [
          {"key": "cleric", "name": "Cleric", "type": "CharacterClass"}
        ],
        "tags": [],
        "dice": []
      }),
      Race.fromJson({
        "_meta": {"language": "EN", "createdBy": "__repo__"},
        "key": "35a7f478-a172-48d4-904c-24235fac4425",
        "name": "Human",
        "description":
            "Your faith is diverse. Choose one wizard spell. You can cast and be granted that spell as if it was a cleric spell.",
        "explanation": "",
        "classKeys": [
          {"key": "cleric", "name": "Cleric", "type": "CharacterClass"}
        ],
        "tags": [],
        "dice": []
      }),
      Race.fromJson({
        "_meta": {"language": "EN", "createdBy": "__repo__"},
        "key": "4988b58e-8b1e-4204-a94c-e4416bfd0f7a",
        "name": "Elf",
        "description":
            "The sap of the elder trees flows within you. In addition to any other attunements, the Great Forest is always considered your land.",
        "explanation": "",
        "classKeys": [
          {"key": "druid", "name": "Druid", "type": "CharacterClass"}
        ],
        "tags": [],
        "dice": []
      }),
      Race.fromJson({
        "_meta": {"language": "EN", "createdBy": "__repo__"},
        "key": "85bbb517-d3a3-4918-832c-bf2a428ab588",
        "name": "Human",
        "description":
            "As your people learned to bind animals to field and farm, so too are you bound to them. You may always take the shape of any domesticated animal, in addition to your normal options.",
        "explanation": "",
        "classKeys": [
          {"key": "druid", "name": "Druid", "type": "CharacterClass"}
        ],
        "tags": [],
        "dice": []
      }),
      Race.fromJson({
        "_meta": {"language": "EN", "createdBy": "__repo__"},
        "key": "b3758f36-1b0e-4ddb-bdd8-ef00cf9b8295",
        "name": "Halfling",
        "description":
            "You sing the healing songs of spring and brook. When you Make Camp, you and your allies heal +1d6.",
        "explanation": "",
        "classKeys": [
          {"key": "druid", "name": "Druid", "type": "CharacterClass"}
        ],
        "tags": [],
        "dice": []
      }),
      Race.fromJson({
        "_meta": {"language": "EN", "createdBy": "__repo__"},
        "key": "a545c44b-7a25-4224-82d0-1b33173e901b",
        "name": "Dwarf",
        "description":
            "When you share a drink with someone, you may Parley with them using CON instead of CHA.",
        "explanation": "",
        "classKeys": [
          {"key": "fighter", "name": "Fighter", "type": "CharacterClass"}
        ],
        "tags": [],
        "dice": []
      }),
      Race.fromJson({
        "_meta": {"language": "EN", "createdBy": "__repo__"},
        "key": "57600856-b738-426e-bedd-a3175f824c00",
        "name": "Elf",
        "description":
            "Choose one weapon-you can always treat weapons of that type as if they had the precise tag.",
        "explanation": "",
        "classKeys": [
          {"key": "fighter", "name": "Fighter", "type": "CharacterClass"}
        ],
        "tags": [],
        "dice": []
      }),
      Race.fromJson({
        "_meta": {"language": "EN", "createdBy": "__repo__"},
        "key": "ceeca68d-0e0e-480c-9a8e-a3b50bb4111a",
        "name": "Halfling",
        "description":
            "When you Defy Danger and use your small size to your advantage, take +1.",
        "explanation": "",
        "classKeys": [
          {"key": "fighter", "name": "Fighter", "type": "CharacterClass"}
        ],
        "tags": [],
        "dice": []
      }),
      Race.fromJson({
        "_meta": {"language": "EN", "createdBy": "__repo__"},
        "key": "2177dfa4-4b69-45b2-b495-041664015808",
        "name": "Human",
        "description":
            "Once per battle you may reroll a single damage roll (yours or someone else's).",
        "explanation": "",
        "classKeys": [
          {"key": "fighter", "name": "Fighter", "type": "CharacterClass"}
        ],
        "tags": [],
        "dice": []
      }),
      Race.fromJson({
        "_meta": {"language": "EN", "createdBy": "__repo__"},
        "key": "faf9eb5f-3f91-4eb4-ba25-cc81e1c4379a",
        "name": "Human",
        "description":
            "When you pray for guidance, even for a moment, and ask, \"What here is evil?\" the GM will tell you, honestly.",
        "explanation": "",
        "classKeys": [
          {"key": "paladin", "name": "Paladin", "type": "CharacterClass"}
        ],
        "tags": [],
        "dice": []
      }),
      Race.fromJson({
        "_meta": {"language": "EN", "createdBy": "__repo__"},
        "key": "c5f7bf31-ea00-4ec7-aa27-5e45e4898539",
        "name": "Elf",
        "description":
            "When you Undertake a Perilous Journey through wilderness whatever job you take you succeed as if you rolled a 10+.",
        "explanation": "",
        "classKeys": [
          {"key": "ranger", "name": "Ranger", "type": "CharacterClass"}
        ],
        "tags": [],
        "dice": []
      }),
      Race.fromJson({
        "_meta": {"language": "EN", "createdBy": "__repo__"},
        "key": "83f43be2-e604-4930-9e28-12c62294bb32",
        "name": "Human",
        "description":
            "When you Make Camp in a dungeon or city, you don't need to consume a ration.",
        "explanation": "",
        "classKeys": [
          {"key": "ranger", "name": "Ranger", "type": "CharacterClass"}
        ],
        "tags": [],
        "dice": []
      }),
      Race.fromJson({
        "_meta": {"language": "EN", "createdBy": "__repo__"},
        "key": "3fe3c5de-4f0a-44af-9c79-23955b1b33f4",
        "name": "Halfling",
        "description": "When you attack with a ranged weapon, deal +2 damage.",
        "explanation": "",
        "classKeys": [
          {"key": "thief", "name": "Thief", "type": "CharacterClass"}
        ],
        "tags": [],
        "dice": []
      }),
      Race.fromJson({
        "_meta": {"language": "EN", "createdBy": "__repo__"},
        "key": "a4eb5d9c-6f54-4418-bb0b-2368bb826c36",
        "name": "Human",
        "description":
            "You are a professional. When you Spout Lore or Discern Realities about criminal activities, take +1.",
        "explanation": "",
        "classKeys": [
          {"key": "thief", "name": "Thief", "type": "CharacterClass"}
        ],
        "tags": [],
        "dice": []
      }),
      Race.fromJson({
        "_meta": {"language": "EN", "createdBy": "__repo__"},
        "key": "24d11979-8018-4a69-95a0-346f4bbcad5c",
        "name": "Elf",
        "description":
            "Magic is as natural as breath to you. Detect Magic is a cantrip for you.",
        "explanation": "",
        "classKeys": [
          {"key": "wizard", "name": "Wizard", "type": "CharacterClass"}
        ],
        "tags": [],
        "dice": []
      }),
      Race.fromJson({
        "_meta": {"language": "EN", "createdBy": "__repo__"},
        "key": "0b0d4852-8757-410e-90ab-e1f29319bc2e",
        "name": "Human",
        "description":
            "Choose one Cleric spell. You can cast it as if it was a Wizard spell.",
        "explanation": "",
        "classKeys": [
          {"key": "wizard", "name": "Wizard", "type": "CharacterClass"}
        ],
        "tags": [],
        "dice": []
      }),
      Race.fromJson({
        "_meta": {"language": "EN", "createdBy": "__repo__"},
        "key": "b303254e-631d-4b91-aa9b-caa9b7e1e406",
        "name": "Salamander",
        "description": "Non-magical heat and fire cannot harm you.",
        "explanation": "",
        "classKeys": [
          {"key": "immolator", "name": "Immolator", "type": "CharacterClass"}
        ],
        "tags": [],
        "dice": []
      }),
      Race.fromJson({
        "_meta": {"language": "EN", "createdBy": "__repo__"},
        "key": "8ac5f523-1005-4b14-a0e0-9436effdb2fc",
        "name": "Human",
        "description":
            "When you Make Camp next to a large, open flame, regain all of your HP.",
        "explanation": "",
        "classKeys": [
          {"key": "immolator", "name": "Immolator", "type": "CharacterClass"}
        ],
        "tags": [],
        "dice": []
      }),
      Race.fromJson({
        "_meta": {"language": "EN", "createdBy": "__repo__"},
        "key": "1a9183de-262a-4d17-8c15-c8b95f30834b",
        "name": "Outsider",
        "description":
            "You may be elf, dwarf, halfling, or human, but you and your people are not from around here. At the beginning of each session, the GM will ask you something about your homeland, why you left, or what you left behind. If you answer them, mark XP.",
        "explanation": "",
        "classKeys": [
          {"key": "barbarian", "name": "Barbarian", "type": "CharacterClass"}
        ],
        "tags": [],
        "dice": []
      })
    ];

==> dungeon_world_data-3.1.0.tar.gz: lib/data/en-US/races.dart <==
import 'package:dungeon_world_data/race.dart';

List<Race> getRaceList() => [
      Race.fromJson({
        "_meta": {"language": "EN", "createdBy": "__repo__"},
        "key": "c0193cdc-e318-44e5-8229-fbbaf3a98936",
        "name": "Elf",
        "description":
            "When you enter an important location (your call) you can ask the GM for one fact from the history of that location.",
        "explanation": "",
        "classKeys": [
          {"key": "bard", "name": "Bard", "type": "CharacterClass"}
        ],
        "tags": [],
        "dice": []
      }),
      Race.fromJson({
        "_meta": {"language": "EN", "createdBy": "__repo__"},
        "key": "6ff63a18-529e-47d8-902e-8093808a9afa",
        "name": "Human",
        "description":
            "When you first enter a civilized settlement someone who respects the custom of hospitality to minstrels will take you in as their guest.",
        "explanation": "",
        "classKeys": [
          {"key": "bard", "name": "Bard", "type": "CharacterClass"}
        ],
        "tags": [],
        "dice": []
      }),
      Race.fromJson({
        "_meta": {"language": "EN", "createdBy": "__repo__"},
        "key": "a300fc64-19b4-4615-98f1-87dea6048cf2",
        "name": "Dwarf",
        "description":
            "You are one with stone. When you Commune you are also granted a special version of Words of the Unspeaking as a rote which only works on stone.",
        "explanation": "",
        "classKeys": [
          {"key": "cleric", "name": "Cleric", "type": "CharacterClass"}
        ],
        "tags": [],
        "dice": []
      }),
      Race.fromJson({
        "_meta": {"language": "EN", "createdBy": "__repo__"},
        "key": "35a7f478-a172-48d4-904c-24235fac4425",
        "name": "Human",
        "description":
            "Your faith is diverse. Choose one wizard spell. You can cast and be granted that spell as if it was a cleric spell.",
        "explanation": "",
        "classKeys": [
          {"key": "cleric", "name": "Cleric", "type": "CharacterClass"}
        ],
        "tags": [],
        "dice": []
      }),
      Race.fromJson({
        "_meta": {"language": "EN", "createdBy": "__repo__"},
        "key": "4988b58e-8b1e-4204-a94c-e4416bfd0f7a",
        "name": "Elf",
        "description":
            "The sap of the elder trees flows within you. In addition to any other attunements, the Great Forest is always considered your land.",
        "explanation": "",
        "classKeys": [
          {"key": "druid", "name": "Druid", "type": "CharacterClass"}
        ],
        "tags": [],
        "dice": []
      }),
      Race.fromJson({
        "_meta": {"language": "EN", "createdBy": "__repo__"},
        "key": "85bbb517-d3a3-4918-832c-bf2a428ab588",
        "name": "Human",
        "description":
            "As your people learned to bind animals to field and farm, so too are you bound to them. You may always take the shape of any domesticated animal, in addition to your normal options.",
        "explanation": "",
        "classKeys": [
          {"key": "druid", "name": "Druid", "type": "CharacterClass"}
        ],
        "tags": [],
        "dice": []
      }),
      Race.fromJson({
        "_meta": {"language": "EN", "createdBy": "__repo__"},
        "key": "b3758f36-1b0e-4ddb-bdd8-ef00cf9b8295",
        "name": "Halfling",
        "description":
            "You sing the healing songs of spring and brook. When you Make Camp, you and your allies heal +1d6.",
        "explanation": "",
        "classKeys": [
          {"key": "druid", "name": "Druid", "type": "CharacterClass"}
        ],
        "tags": [],
        "dice": []
      }),
      Race.fromJson({
        "_meta": {"language": "EN", "createdBy": "__repo__"},
        "key": "a545c44b-7a25-4224-82d0-1b33173e901b",
        "name": "Dwarf",
        "description":
            "When you share a drink with someone, you may Parley with them using CON instead of CHA.",
        "explanation": "",
        "classKeys": [
          {"key": "fighter", "name": "Fighter", "type": "CharacterClass"}
        ],
        "tags": [],
        "dice": []
      }),
      Race.fromJson({
        "_meta": {"language": "EN", "createdBy": "__repo__"},
        "key": "57600856-b738-426e-bedd-a3175f824c00",
        "name": "Elf",
        "description":
            "Choose one weapon-you can always treat weapons of that type as if they had the precise tag.",
        "explanation": "",
        "classKeys": [
          {"key": "fighter", "name": "Fighter", "type": "CharacterClass"}
        ],
        "tags": [],
        "dice": []
      }),
      Race.fromJson({
        "_meta": {"language": "EN", "createdBy": "__repo__"},
        "key": "ceeca68d-0e0e-480c-9a8e-a3b50bb4111a",
        "name": "Halfling",
        "description": "When you Defy Danger and use your small size to your advantage, take +1.",
        "explanation": "",
        "classKeys": [
          {"key": "fighter", "name": "Fighter", "type": "CharacterClass"}
        ],
        "tags": [],
        "dice": []
      }),
      Race.fromJson({
        "_meta": {"language": "EN", "createdBy": "__repo__"},
        "key": "2177dfa4-4b69-45b2-b495-041664015808",
        "name": "Human",
        "description":
            "Once per battle you may reroll a single damage roll (yours or someone else's).",
        "explanation": "",
        "classKeys": [
          {"key": "fighter", "name": "Fighter", "type": "CharacterClass"}
        ],
        "tags": [],
        "dice": []
      }),
      Race.fromJson({
        "_meta": {"language": "EN", "createdBy": "__repo__"},
        "key": "faf9eb5f-3f91-4eb4-ba25-cc81e1c4379a",
        "name": "Human",
        "description":
            "When you pray for guidance, even for a moment, and ask, \"What here is evil?\" the GM will tell you, honestly.",
        "explanation": "",
        "classKeys": [
          {"key": "paladin", "name": "Paladin", "type": "CharacterClass"}
        ],
        "tags": [],
        "dice": []
      }),
      Race.fromJson({
        "_meta": {"language": "EN", "createdBy": "__repo__"},
        "key": "c5f7bf31-ea00-4ec7-aa27-5e45e4898539",
        "name": "Elf",
        "description":
            "When you Undertake a Perilous Journey through wilderness whatever job you take you succeed as if you rolled a 10+.",
        "explanation": "",
        "classKeys": [
          {"key": "ranger", "name": "Ranger", "type": "CharacterClass"}
        ],
        "tags": [],
        "dice": []
      }),
      Race.fromJson({
        "_meta": {"language": "EN", "createdBy": "__repo__"},
        "key": "83f43be2-e604-4930-9e28-12c62294bb32",
        "name": "Human",
        "description":
            "When you Make Camp in a dungeon or city, you don't need to consume a ration.",
        "explanation": "",
        "classKeys": [
          {"key": "ranger", "name": "Ranger", "type": "CharacterClass"}
        ],
        "tags": [],
        "dice": []
      }),
      Race.fromJson({
        "_meta": {"language": "EN", "createdBy": "__repo__"},
        "key": "3fe3c5de-4f0a-44af-9c79-23955b1b33f4",
        "name": "Halfling",
        "description": "When you attack with a ranged weapon, deal +2 damage.",
        "explanation": "",
        "classKeys": [
          {"key": "thief", "name": "Thief", "type": "CharacterClass"}
        ],
        "tags": [],
        "dice": []
      }),
      Race.fromJson({
        "_meta": {"language": "EN", "createdBy": "__repo__"},
        "key": "a4eb5d9c-6f54-4418-bb0b-2368bb826c36",
        "name": "Human",
        "description":
            "You are a professional. When you Spout Lore or Discern Realities about criminal activities, take +1.",
        "explanation": "",
        "classKeys": [
          {"key": "thief", "name": "Thief", "type": "CharacterClass"}
        ],
        "tags": [],
        "dice": []
      }),
      Race.fromJson({
        "_meta": {"language": "EN", "createdBy": "__repo__"},
        "key": "24d11979-8018-4a69-95a0-346f4bbcad5c",
        "name": "Elf",
        "description": "Magic is as natural as breath to you. Detect Magic is a cantrip for you.",
        "explanation": "",
        "classKeys": [
          {"key": "wizard", "name": "Wizard", "type": "CharacterClass"}
        ],
        "tags": [],
        "dice": []
      }),
      Race.fromJson({
        "_meta": {"language": "EN", "createdBy": "__repo__"},
        "key": "0b0d4852-8757-410e-90ab-e1f29319bc2e",
        "name": "Human",
        "description": "Choose one Cleric spell. You can cast it as if it was a Wizard spell.",
        "explanation": "",
        "classKeys": [
          {"key": "wizard", "name": "Wizard", "type": "CharacterClass"}
        ],
        "tags": [],
        "dice": []
      }),
      Race.fromJson({
        "_meta": {"language": "EN", "createdBy": "__repo__"},
        "key": "b303254e-631d-4b91-aa9b-caa9b7e1e406",
        "name": "Salamander",
        "description": "Non-magical heat and fire cannot harm you.",
        "explanation": "",
        "classKeys": [
          {"key": "immolator", "name": "Immolator", "type": "CharacterClass"}
        ],
        "tags": [],
        "dice": []
      }),
      Race.fromJson({
        "_meta": {"language": "EN", "createdBy": "__repo__"},
        "key": "8ac5f523-1005-4b14-a0e0-9436effdb2fc",
        "name": "Human",
        "description": "When you Make Camp next to a large, open flame, regain all of your HP.",
        "explanation": "",
        "classKeys": [
          {"key": "immolator", "name": "Immolator", "type": "CharacterClass"}
        ],
        "tags": [],
        "dice": []
      }),
      Race.fromJson({
        "_meta": {"language": "EN", "createdBy": "__repo__"},
        "key": "1a9183de-262a-4d17-8c15-c8b95f30834b",
        "name": "Outsider",
        "description":
            "You may be elf, dwarf, halfling, or human, but you and your people are not from around here. At the beginning of each session, the GM will ask you something about your homeland, why you left, or what you left behind. If you answer them, mark XP.",
        "explanation": "",
        "classKeys": [
          {"key": "barbarian", "name": "Barbarian", "type": "CharacterClass"}
        ],
        "tags": [],
        "dice": []
      })
    ];
